@@ -2,7 +2,7 @@
 from django.contrib import admin
 
 from network.base.models import Antenna, AntennaType, DemodData, FrequencyRange, Observation, \
-    Satellite, Station
+    Satellite, Station, StationStatusLog
 from network.base.utils import export_as_csv, export_station_status
 
 
@@ -86,7 +86,9 @@ class StationAdmin(admin.ModelAdmin):
 
     def get_email(self, obj):  # pylint: disable=no-self-use
         """Return station owner email address"""
-        return obj.owner.email
+        if obj.owner:
+            return obj.owner.email
+        return None
 
     get_email.admin_order_field = 'email'
     get_email.short_description = 'Owner Email'
@@ -99,6 +101,14 @@ class StationAdmin(admin.ModelAdmin):
         return actions
 
 
+@admin.register(StationStatusLog)
+class StationStatusLogAdmin(admin.ModelAdmin):
+    """Define StationStatusLog view in django admin UI"""
+    list_display = ('id', 'station', 'status', 'changed')
+    list_filter = ('station', 'status')
+    search_fields = ('id', 'station__id')
+
+
 @admin.register(Satellite)
 class SatelliteAdmin(admin.ModelAdmin):
     """Define Satellite view in django admin UI"""
