@@ -1,11 +1,14 @@
-/* global moment, d3, Slider, calcPolarPlotSVG */
+/* global moment, d3, Slider, calcPolarPlotSVG, tempusDominus */
 
 $(document).ready( function(){
+
+    $('.selectpicker').selectpicker();
+
     $('#advanced-options').click(function(){
-        if($('button span').hasClass('glyphicon-chevron-down')) {
-            $(this).html('<span class="glyphicon glyphicon-chevron-up"></span> Hide Advanced Options');
+        if($('button span').hasClass('bi-chevron-down')) {
+            $(this).html('<span class="bi bi-chevron-up"></span> Hide Advanced Options');
         } else {
-            $(this).html('<span class="glyphicon glyphicon-chevron-down"></span> Show Advanced Options');
+            $(this).html('<span class="bi bi-chevron-down"></span> Show Advanced Options');
         }
     });
 
@@ -29,15 +32,57 @@ $(document).ready( function(){
         }
     });
 
-    $('#default-split-duration').click(function() {
+    const custom_split_formgroup = $('#split-duration-formgroup');
+    function reset_split_duration() {
+        custom_split_formgroup.removeClass('has-error');
         $('#split-duration-custom').remove();
+        $('#split-duration-span').remove();
+    }
+
+    $('#default-split-duration').click(function() {
+        reset_split_duration();
     });
 
+    function get_errors(code, min_val) {
+        switch(code) {
+        case 1:
+            return 'Value is not a number.';
+        case 2:
+            return 'Enter a value equal or greater than ' + min_val + '.';
+        default:
+            return 'Invalid input.';
+        }
+    }
+
     $('#custom-split-duration').click(function() {
         if (!$('#split-duration-custom').length){
             var value = $('#default-split-duration input')[0].value;
             var min_value = $('#default-split-duration input')[0].dataset.min;
-            $('#split-duration-status').append('<input type="number" name="split_duration_custom" id="split-duration-custom" class="duration-number-input" min="' + min_value + '" step="1" value="' + value +'"/>');
+            $('#split-duration-status').append('<input type="number" name="split_duration_custom" id="split-duration-custom" class="duration-number-input form-control" min="' + min_value + '" step="1" value="' + value +'"/>');
+            $('#split-duration-status').append('<span id="split-duration-span"></span>');
+            const custom_split = $('#split-duration-custom');
+            custom_split.on('input', function () {
+                var has_error = 0;
+                if(isNaN(custom_split.val()) || custom_split.val() == '') {
+                    has_error = 1;
+                } else if(parseInt(custom_split.val()) < min_value) {
+                    has_error = 2;
+                }
+
+                if(has_error) {
+                    custom_split_formgroup.addClass('has-error');
+                    $('#split-duration-span').addClass('alert-error');
+                    $('#calculate-observation').prop('disabled', true);
+                    $('#schedule-observation').prop('disabled', true);
+                    $('#split-duration-span').html(get_errors(has_error, min_value));
+                } else {
+                    custom_split_formgroup.removeClass('has-error');
+                    $('#split-duration-span').removeClass('alert-error');
+                    $('#calculate-observation').prop('disabled', false);
+                    $('#schedule-observation').prop('disabled', false);
+                    $('#split-duration-span').html('');
+                }
+            });
         }
     });
 
@@ -48,7 +93,7 @@ $(document).ready( function(){
     $('#custom-break-duration').click(function() {
         if (!$('#break-duration-custom').length){
             var value = $('#default-break-duration input')[0].value;
-            $('#break-duration-status').append('<input type="number" name="break_duration_custom" id="break-duration-custom" class="duration-number-input" min="0" step="1" value="' + value +'"/>');
+            $('#break-duration-status').append('<input type="number" name="break_duration_custom" id="break-duration-custom" class="duration-number-input form-control" min="0" step="1" value="' + value +'"/>');
         }
     });
 
@@ -56,12 +101,12 @@ $(document).ready( function(){
         return `
             <option value="` + station.id + `"
                     data-content='<div class="station-option">
-                                    <span class="label label-` + station.status_display.toLowerCase() +`">
+                                    <span class="badge badge-` + station.status_display.toLowerCase() +`">
                                       ` + station.id +
-                                    `</span>
+            `</span>
                                     <span class="station-description">
                                       ` + station.name +
-                                    `</span>
+            `</span>
                                   </div>'>
             </option>
         `;
@@ -73,6 +118,9 @@ $(document).ready( function(){
         if (filters.station) {
             data.station_id = filters.station;
         }
+        if (filters.center_frequency) {
+            data.center_frequency = filters.center_frequency;
+        }
         $.ajax({
             type: 'POST',
             url: url,
@@ -129,29 +177,34 @@ $(document).ready( function(){
         });
     }
 
-    function create_transmitter_option(satellite, transmitter){
+    function create_transmitter_option(satellite, transmitter) {
+        const transmitter_freq = (transmitter.type === 'Transponder') ? (transmitter.downlink_low/1e6).toFixed(3) + ' - ' +  (transmitter.downlink_high/1e6).toFixed(3): (transmitter.downlink_low/1e6).toFixed(3);
         return `
             <option data-satellite="` + satellite + `"
+                    data-transmitter-type="` + transmitter.type + `"
+                    data-downlink-low="` + transmitter.downlink_low + `"
+                    data-downlink-high="` + transmitter.downlink_high + `"
+                    data-downlink-drift="` + transmitter.downlink_drift + `"
                     value="` + transmitter.uuid + `"
                     data-success-rate="` + transmitter.success_rate + `"
                     data-content='<div class="transmitter-option">
                                     <div class="transmitter-description">
-                                      ` + transmitter.description + ' - ' + (transmitter.downlink_low/1e6).toFixed(3) + ' MHz - ' + transmitter.mode +
-                                    `</div>
+                                      ` + transmitter.description + ' | ' + transmitter_freq + ' MHz | ' + transmitter.mode +
+            `</div>
                                     <div class="progress">
-                                      <div class="progress-bar progress-bar-success transmitter-good"
+                                      <div class="progress-bar pb-success transmitter-good"
                                         data-toggle="tooltip" data-placement="bottom"
                                         title="` + transmitter.success_rate + '% (' + transmitter.good_count + `) Good"
                                         style="width:` + transmitter.success_rate + `%"></div>
-                                      <div class="progress-bar progress-bar-warning transmitter-unknown"
+                                      <div class="progress-bar pb-warning transmitter-unknown"
                                         data-toggle="tooltip" data-placement="bottom"
                                         title="` + transmitter.unknown_rate + '% (' + transmitter.unknown_count + `) Unknown"
                                         style="width:` + transmitter.unknown_rate + `%"></div>
-                                      <div class="progress-bar progress-bar-danger transmitter-bad"
+                                      <div class="progress-bar pb-danger transmitter-bad"
                                         data-toggle="tooltip" data-placement="bottom"
                                         title="` + transmitter.bad_rate + '% (' + transmitter.bad_count + `) Bad"
                                         style="width:` + transmitter.bad_rate + `%"></div>
-                                      <div class="progress-bar progress-bar-info transmitter-future"
+                                      <div class="progress-bar pb-info transmitter-future"
                                         data-toggle="tooltip" data-placement="bottom"
                                         title="` + transmitter.future_rate + '% (' + transmitter.future_count + `) Future"
                                         style="width:` + transmitter.future_rate + `%"></div>
@@ -346,6 +399,7 @@ $(document).ready( function(){
         var station_counter = 0;
         var warn_min_obs = parseInt(this.dataset.warnMinObs);
         var transmitter_uuid = $('#transmitter-selection').find(':selected').val();
+        var center_frequency = frequency_input.data('is-valid') ? frequency_input.val() : 0;
         $.each(suggested_data, function(i, station){
             let obs_counted = obs_counter;
             $.each(station.times, function(j, observation){
@@ -356,6 +410,9 @@ $(document).ready( function(){
                     $('#windows-data').append('<input type="hidden" name="obs-' + obs_counter + '-end" value="' + end + '">');
                     $('#windows-data').append('<input type="hidden" name="obs-' + obs_counter + '-ground_station" value="' + station.id + '">');
                     $('#windows-data').append('<input type="hidden" name="obs-' + obs_counter + '-transmitter_uuid" value="' + transmitter_uuid + '">');
+                    if (center_frequency) {
+                        $('#windows-data').append('<input type="hidden" name="obs-' + obs_counter + '-center_frequency" value="' + center_frequency + '">');
+                    }
                     obs_counter += 1;
                 }
             });
@@ -391,24 +448,127 @@ $(document).ready( function(){
         var maxStartDate = moment().utc().add(minStart + maxRange - minRange, 'm').format('YYYY-MM-DD HH:mm');
         var minEndDate = moment().utc().add(minEnd, 'm').format('YYYY-MM-DD HH:mm');
         var maxEndDate = moment().utc().add(minStart + maxRange, 'm').format('YYYY-MM-DD HH:mm');
-        $('#datetimepicker-start').datetimepicker({
-            useCurrent: false //https://github.com/Eonasdan/bootstrap-datetimepicker/issues/1075
-        });
-        $('#datetimepicker-start').data('DateTimePicker').date(minStartDate);
-        $('#datetimepicker-start').data('DateTimePicker').minDate(minStartDate);
-        $('#datetimepicker-start').data('DateTimePicker').maxDate(maxStartDate);
-        $('#datetimepicker-end').datetimepicker({
-            useCurrent: false //https://github.com/Eonasdan/bootstrap-datetimepicker/issues/1075
-        });
-        $('#datetimepicker-end').data('DateTimePicker').date(minEndDate);
-        $('#datetimepicker-end').data('DateTimePicker').minDate(minEndDate);
-        $('#datetimepicker-end').data('DateTimePicker').maxDate(maxEndDate);
-        $('#datetimepicker-start').on('dp.change',function (e) {
-            var newMinEndDate = e.date.clone().add(minRange, 'm');
-            if ($('#datetimepicker-end').data('DateTimePicker').date() < newMinEndDate) {
-                $('#datetimepicker-end').data('DateTimePicker').date(newMinEndDate);
+
+        tempusDominus.extend(window.tempusDominus.plugins.customDateFormat);
+        var start = new tempusDominus.TempusDominus(document.getElementById('datetimepicker-start'), {
+            useCurrent: false,
+            defaultDate: minStartDate,
+            restrictions:{
+                minDate: minStartDate,
+                maxDate: maxStartDate
+            },
+            display: {
+                icons: {
+                    type: 'icons',
+                    time: 'bi bi-clock',
+                    date: 'bi bi-calendar3',
+                    up: 'bi bi-arrow-up',
+                    down: 'bi bi-arrow-down',
+                    previous: 'bi bi-chevron-left',
+                    next: 'bi bi-chevron-right',
+                    today: 'bi bi-calendar-check',
+                    clear: 'bi bi-trash',
+                    close: 'bi bi-x-lg'
+                },
+                sideBySide: true,
+                components: {
+                    useTwentyfourHour: true
+                },
+                buttons: {
+                    close: true
+                }
+            },
+            localization: {
+                format: 'yyyy-MM-dd HH:mm'
             }
-            $('#datetimepicker-end').data('DateTimePicker').minDate(newMinEndDate);
+        });
+        var end = new tempusDominus.TempusDominus(document.getElementById('datetimepicker-end'), {
+            useCurrent: false,
+            defaultDate: minEndDate,
+            restrictions:{
+                minDate: minEndDate,
+                maxDate: maxEndDate
+            },
+            display: {
+                icons: {
+                    type: 'icons',
+                    time: 'bi bi-clock',
+                    date: 'bi bi-calendar3',
+                    up: 'bi bi-arrow-up',
+                    down: 'bi bi-arrow-down',
+                    previous: 'bi bi-chevron-left',
+                    next: 'bi bi-chevron-right',
+                    today: 'bi bi-calendar-check',
+                    clear: 'bi bi-trash',
+                    close: 'bi bi-x-lg'
+                },
+                sideBySide: true,
+                components: {
+                    useTwentyfourHour: true
+                },
+                buttons: {
+                    close: true
+                }
+            },
+            localization: {
+                format: 'yyyy-MM-dd HH:mm'
+            }
+        });
+        const otherValidFormats = [
+            'YYYY-MM-DD H:mm', 'YYYY-MM-DD HH', 'YYYY-MM-DD H', 'YYYY-MM-DD HH:m',
+            'YYYY-MM-DD H:m', 'YYYY-MM-D HH:mm', 'YYYY-MM-D H:mm', 'YYYY-MM-D HH',
+            'YYYY-MM-D H', 'YYYY-MM-D HH:m', 'YYYY-MM-D H:m', 'YYYY-M-D HH:mm', 'YYYY-M-D H:mm',
+            'YYYY-M-D HH', 'YYYY-M-D H', 'YYYY-M-D HH:m', 'YYYY-M-D H:m', 'YYYY-M-DD HH:mm',
+            'YYYY-M-DD H:mm', 'YYYY-M-DD HH', 'YYYY-M-DD H', 'YYYY-M-DD HH:m', 'YYYY-M-DD H:m'
+        ];
+        $('#datetimepicker-start input').on('blur', function () {
+            if (!moment(this.value, 'YYYY-MM-DD HH:mm', true).isValid()){
+                var date = moment(this.value, otherValidFormats, true);
+                if (date.isValid()){
+                    var newDate = date.format('YYYY-MM-DD HH:mm');
+                    start.dates.setFromInput(newDate);
+                } else {
+                    start.dates.setFromInput(minStartDate);
+                }
+            }
+        });
+        $('#datetimepicker-end input').on('blur', function () {
+            if (!moment(this.value, 'YYYY-MM-DD HH:mm', true).isValid()){
+                var date = moment(this.value, otherValidFormats, true);
+                if (date.isValid()){
+                    var newDate = date.format('YYYY-MM-DD HH:mm');
+                    end.dates.setFromInput(newDate);
+                } else {
+                    end.dates.setFromInput(maxEndDate);
+                }
+            }
+        });
+        start.subscribe(tempusDominus.Namespace.events.error, (e) => {
+            if(e.oldDate){
+                var oldDateFormatted = moment(e.oldDate).format('YYYY-MM-DD HH:mm');
+                start.dates.setFromInput(oldDateFormatted);
+            } else {
+                start.dates.setFromInput(minStartDate);
+            }
+        });
+        end.subscribe(tempusDominus.Namespace.events.error, (e) => {
+            if(e.oldDate){
+                var oldDateFormatted = moment(e.oldDate).format('YYYY-MM-DD HH:mm');
+                end.dates.setFromInput(oldDateFormatted);
+            } else {
+                end.dates.setFromInput(maxEndDate);
+            }
+        });
+        start.subscribe(tempusDominus.Namespace.events.change, (e) => {
+            var newMinEndDate = moment(e.date).add(minRange, 'm');
+            var newMinEndDateFormatted = newMinEndDate.format('YYYY-MM-DD HH:mm');
+            if (moment(end.dates.lastPicked) < newMinEndDate) {
+                end.dates.setFromInput(newMinEndDateFormatted);
+            }
+            end.updateOptions({
+                restrictions: {minDate: newMinEndDateFormatted},
+                localization: {format: 'yyyy-MM-dd HH:mm'}
+            });
         });
     }
 
@@ -427,6 +587,7 @@ $(document).ready( function(){
     }
 
     $('#satellite-selection').on('changed.bs.select', function() {
+        reset_split_duration();
         var satellite = $(this).find(':selected').data('norad');
         var station = $('#form-obs').data('obs-filter-station');
         select_proper_transmitters({
@@ -436,20 +597,97 @@ $(document).ready( function(){
         initiliaze_calculation(false);
     });
 
-    $('#transmitter-selection').on('changed.bs.select', function() {
-        var transmitter = $(this).find(':selected').val();
+
+    function search_for_stations(transmitter_object) {
+        reset_split_duration();
+        var transmitter = transmitter_object.val();
+        var downlink_low = transmitter_object.data('downlink-low');
         var station = $('#form-obs').data('obs-filter-station');
+        var center_frequency = (frequency_input.data('is-valid')) ? frequency_input.val() : downlink_low;
         select_proper_stations({
             transmitter: transmitter,
-            station: station
-        }, function(){
-            if (obs_filter && obs_filter_dates && obs_filter_station && obs_filter_satellite){
+            station: station,
+            center_frequency: center_frequency
+        }, function() {
+            if (obs_filter && obs_filter_dates && obs_filter_station && obs_filter_satellite) {
                 $('#obs-selection-tools').hide();
                 $('#truncate-overlapped').click();
                 calculate_observation();
             }
         });
         initiliaze_calculation(false);
+    }
+
+    function format_frequency(val) {
+        if (!Number.isInteger(val)) {
+            return 'Error';
+        }
+
+        const unit_table = ['Hz', 'kHz', 'MHz', 'GHz'];
+        const div = Math.floor(Math.log10(val) / 3);
+        const unit = unit_table[(div > 3) ? 3 : div];
+
+        return val / (Math.pow(1000, (div > 3) ? 3 : div)) + ' ' + unit;
+    }
+
+    const frequency_input_format = $('#frequency-input-format');
+    const frequency_input = $('#center-frequency-input');
+    const frequency_formgroup = $('#center-frequency-formgroup');
+    const calculate_button = $('#calculate-observation');
+    const schedule_observation = $('#schedule-observation');
+    const transmitter_selection = $('#transmitter-selection');
+    const frequency_errors = { '1': 'Value is not a number', '2': 'Value out of range' };
+
+    frequency_input.on('input', function () {
+        var val = parseInt($(this).val());
+        const min = parseInt(frequency_input.attr('min'));
+        const max = parseInt(frequency_input.attr('max'));
+        var has_error = 0;
+
+        if (isNaN(val)) {
+            has_error = 1;
+        }
+        else if (val < min || val > max) {
+            has_error = 2;
+        }
+
+        if (!has_error) {
+            frequency_formgroup.removeClass('has-error');
+            frequency_input_format.removeClass('alert-error');
+            frequency_input.data('is-valid', true);
+            frequency_input_format.html(format_frequency(val));
+            calculate_button.prop('disabled', false);
+            schedule_observation.prop('disabled', false);
+            var transmitter_object = transmitter_selection.find(':selected');
+            search_for_stations(transmitter_object);
+        } else {
+            frequency_formgroup.addClass('has-error');
+            frequency_input_format.addClass('alert-error');
+            frequency_input_format.html(frequency_errors[has_error]);
+            calculate_button.prop('disabled', true);
+            schedule_observation.prop('disabled', true);
+            frequency_input.data('is-valid', false);
+        }
+    });
+
+    $('#transmitter-selection').on('changed.bs.select', function () {
+
+        var transmitter_object = $(this).find(':selected');
+        var transmitter_type = transmitter_object.data('transmitter-type');
+        var downlink_high = transmitter_object.data('downlink-high');
+        var downlink_low = transmitter_object.data('downlink-low');
+        var downlink_drift = transmitter_object.data('downlink-drift');
+        if (transmitter_type === 'Transponder') {
+            frequency_input.attr({ 'min': (downlink_drift && downlink_drift < 0) ? downlink_low + downlink_drift : downlink_low, 'max': (downlink_drift && downlink_drift > 0) ? downlink_high + downlink_drift : downlink_high});
+            frequency_input.val(downlink_low);
+            frequency_input.data('is-valid', true);
+            frequency_input_format.html(format_frequency(downlink_low));
+            $('#center-frequency-formgroup').fadeIn('fast');
+        } else {
+            frequency_input.data('is-valid', false);
+            $('#center-frequency-formgroup').fadeOut('fast');
+        }
+        search_for_stations(transmitter_object);
     });
 
     function sort_stations(a, b){
@@ -475,6 +713,10 @@ $(document).ready( function(){
         data.transmitter = $('#transmitter-selection').find(':selected').val();
         data.satellite = $('#satellite-selection').val();
         data.stations = $('#station-selection').val();
+        var center_frequency = frequency_input.data('is-valid') ? frequency_input.val() : 0;
+        if (center_frequency) {
+            data.center_frequency = center_frequency;
+        }
         if (data.satellite.length == 0) {
             $('#windows-data').html('<span class="text-danger">You should select a Satellite first.</span>');
             return;
@@ -503,7 +745,7 @@ $(document).ready( function(){
         if(is_split_duration) {
             var split_duration = parseInt($('#split-duration-custom').val());
             var min_value = parseInt($('#default-split-duration input')[0].dataset.min);
-            if (!isNaN(split_duration) && split_duration > min_value) {
+            if (!isNaN(split_duration) && split_duration >= min_value) {
                 data.split_duration = split_duration;
             }
         }
@@ -725,6 +967,14 @@ $(document).ready( function(){
         $('#satellite-selection').selectpicker('toggle');
     }
 
+    $(document).on('keypress', '.datetimepicker input', function (e) {
+        var code = e.keyCode || e.which;
+        if (code == 13) {
+            e.preventDefault();
+            return false;
+        }
+    });
+
     // Hotkeys bindings
     $(document).bind('keyup', function(event){
         if(document.activeElement.tagName != 'INPUT'){
